"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const key_tree_to_node_tree_1 = require("./key-tree-to-node-tree");
it('should handle empty tree', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', {});
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [],
    });
});
it('should handle undefined tree', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/');
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: undefined,
    });
});
it('should handle leaf nodes', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { hello: undefined });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'hello',
                children: undefined,
            },
        ],
    });
});
it('should handle inner nodes', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { 'hello/': {} });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'hello/',
                children: [],
            },
        ],
    });
});
it('should handle nested nodes', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { 'hello/': { one: undefined, two: undefined } });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'hello/',
                children: [
                    {
                        id: 'one',
                        children: undefined,
                    },
                    {
                        id: 'two',
                        children: undefined,
                    },
                ],
            },
        ],
    });
});
it('should handle nested nodes', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { 'hello/': { 'hello/one': undefined, 'hello/two': undefined } });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'hello/',
                children: [
                    {
                        id: 'hello/one',
                        children: undefined,
                    },
                    {
                        id: 'hello/two',
                        children: undefined,
                    },
                ],
            },
        ],
    });
});
it('should leaf and inner nodes with the same name', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { 'hello/': {}, hello: undefined });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'hello/',
                children: [],
            },
            {
                id: 'hello',
                children: undefined,
            },
        ],
    });
});
it('should sort inner nodes first and alphabetically', () => {
    const result = key_tree_to_node_tree_1.keyTreeToNodeTree('/', { 'b/': {}, c: undefined, 'd/': {}, a: undefined });
    chai_1.expect(result).to.deep.equal({
        id: '/',
        children: [
            {
                id: 'b/',
                children: [],
            },
            {
                id: 'd/',
                children: [],
            },
            {
                id: 'a',
                children: undefined,
            },
            {
                id: 'c',
                children: undefined,
            },
        ],
    });
});
//# sourceMappingURL=key-tree-to-node-tree.specx.js.map